@@ -1,5 +1,5 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 #define __SMTP_H__
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "claws-features.h"
 #endif
 
 #include <glib.h>
@@ -55,13 +55,13 @@ typedef enum
 	SMTPAUTH_CRAM_MD5   = 1 << 1,
 	SMTPAUTH_DIGEST_MD5 = 1 << 2,
 	SMTPAUTH_TLS_AVAILABLE = 1 << 3,
-	SMTPAUTH_PLAIN      = 1 << 4
+	SMTPAUTH_PLAIN      = 1 << 4,
+	SMTPAUTH_OAUTH2     = 1 << 5
 } SMTPAuthType;
 
 typedef enum
 {
 	SMTP_READY,
-	SMTP_CONNECTED,
 	SMTP_HELO,
 	SMTP_EHLO,
 	SMTP_STARTTLS,
@@ -71,6 +71,7 @@ typedef enum
 	SMTP_AUTH_LOGIN_PASS,
 	SMTP_AUTH_CRAM_MD5,
 	SMTP_AUTH_PLAIN,
+	SMTP_AUTH_OAUTH2,
 	SMTP_RCPT,
 	SMTP_DATA,
 	SMTP_SEND_DATA,
